@@ -8,6 +8,7 @@ from continuum.scenarios.transformation_incremental import TransformationIncreme
 from continuum.scenarios.rotations import Rotations
 from continuum.scenarios.permutations import Permutations
 from continuum.scenarios.segmentation import SegmentationClassIncremental
+from continuum.scenarios.hashed import HashedScenario
 
 from continuum.scenarios.scenario_utils import create_subscenario
 
@@ -18,5 +19,6 @@ __all__ = [
     "Rotations",
     "Permutations",
     "TransformationIncremental",
-    "SegmentationClassIncremental"
+    "SegmentationClassIncremental",
+    "HashedScenario"
 ]
