@@ -1,6 +1,6 @@
 # pylint: disable=C0401
 # flake8: noqa
 from continuum.tasks.task_set import TaskSet
-from continuum.tasks.utils import split_train_val
+from continuum.tasks.utils import split_train_val, concat
 
 __all__ = ["TaskSet"]
